@@ -31,7 +31,7 @@ test_that("mc3",{
   diag(data.param)<-0.5
   colnames(data.param) <- rownames(data.param) <- names(dist)
 
-  out.sim.0 <- simulateabn(data.dists = dist,n.chains = 1,n.adapt = 1000,n.thin = 1,n.iter = 1000,data.param = 0.4*data.param, simulate = TRUE,seed = 132,verbose = FALSE)
+  out.sim.0 <- simulateAbn(data.dists = dist,n.chains = 1,n.adapt = 1000,n.thin = 1,n.iter = 1000,data.param = 0.4*data.param, simulate = TRUE,seed = 132,verbose = FALSE)
 
   bsc.compute.0 <- buildscorecache(data.df = out.sim.0, data.dists = dist,  max.parents = 3)
 
@@ -48,7 +48,7 @@ test_that("mc3",{
                   prior.choice = 1)
 
   dag <- mostprobable(score.cache = bsc.compute.0,prior.choice = 1)
-  expect_equal(max(mc3.out$scores),fitabn(dag.m = dag,data.df = out.sim.0,data.dists = dist)$mlik)
+  expect_equal(max(mc3.out$scores),fitabn(object = dag,data.df = out.sim.0,data.dists = dist)$mlik)
 
   mc3.out <- mcmcabn(score.cache = bsc.compute.0,
                      score = "mlik",
@@ -63,13 +63,13 @@ test_that("mc3",{
                      prior.choice = 2)
 
   dag <- mostprobable(score.cache = bsc.compute.0,prior.choice = 2)
-  expect_equal(round(max(mc3.out$scores),digits = 0),round(fitabn(dag.m = dag,data.df = out.sim.0,data.dists = dist)$mlik,digits = 0))
+  expect_equal(round(max(mc3.out$scores),digits = 0),round(fitabn(object = dag,data.df = out.sim.0,data.dists = dist)$mlik,digits = 0))
 
   data.param.eq <- matrix(data = 0,nrow = 5,ncol = 5)
   mc3.out <- mcmcabn(score.cache = bsc.compute.0,
                      score = "mlik",
                      data.dists = dist,
-                     max.parents = 1,
+                     max.parents = 3,
                      mcmc.scheme = c(1000,0,0),
                      seed = 42,
                      verbose = FALSE,
@@ -86,7 +86,7 @@ test_that("mc3",{
   mc3.out <- mcmcabn(score.cache = bsc.compute.0,
                      score = "mlik",
                      data.dists = dist,
-                     max.parents = 1,
+                     max.parents = 3,
                      mcmc.scheme = c(1000,0,0),
                      seed = 42,
                      verbose = FALSE,
@@ -114,7 +114,7 @@ test_that("REV",{
   diag(data.param)<-0.5
   colnames(data.param) <- rownames(data.param) <- names(dist)
 
-  out.sim.0 <- invisible(simulateabn(data.dists = dist,n.chains = 1,n.adapt = 1000,n.thin = 1,n.iter = 1000,data.param = 0.4*data.param, simulate = TRUE,seed = 132))
+  out.sim.0 <- invisible(simulateAbn(data.dists = dist,n.chains = 1,n.adapt = 1000,n.thin = 1,n.iter = 1000,data.param = 0.4*data.param, simulate = TRUE,seed = 132))
 
   bsc.compute.0 <- buildscorecache(data.df = out.sim.0, data.dists = dist,  max.parents = 3)
 
@@ -131,7 +131,7 @@ test_that("REV",{
                      prior.choice = 1)
 
   dag <- mostprobable(score.cache = bsc.compute.0,prior.choice = 1)
-  expect_equal(max(mc3.out$scores),fitabn(dag.m = dag,data.df = out.sim.0,data.dists = dist)$mlik)
+  expect_equal(max(mc3.out$scores),fitabn(object = dag,data.df = out.sim.0,data.dists = dist)$mlik)
 
   expect_silent(mcmcabn(score.cache = bsc.compute.0,
                         score = "mlik",
@@ -160,7 +160,7 @@ test_that("MBR",{
   diag(data.param)<-0.5
   colnames(data.param) <- rownames(data.param) <- names(dist)
 
-  out.sim.0 <- invisible(simulateabn(data.dists = dist,n.chains = 1,n.adapt = 1000,n.thin = 1,n.iter = 1000,data.param = 0.4*data.param, simulate = TRUE,seed = 132))
+  out.sim.0 <- invisible(simulateAbn(data.dists = dist,n.chains = 1,n.adapt = 1000,n.thin = 1,n.iter = 1000,data.param = 0.4*data.param, simulate = TRUE,seed = 132))
 
   bsc.compute.0 <- buildscorecache(data.df = out.sim.0, data.dists = dist,  max.parents = 3)
 
@@ -177,7 +177,7 @@ test_that("MBR",{
                      prior.choice = 2)
 
   dag <- mostprobable(score.cache = bsc.compute.0,prior.choice = 1)
-  expect_equal(max(mc3.out$scores),fitabn(dag.m = dag,data.df = out.sim.0,data.dists = dist)$mlik)
+  expect_equal(max(mc3.out$scores),fitabn(object = dag,data.df = out.sim.0,data.dists = dist)$mlik)
 
   expect_silent(mcmcabn(score.cache = bsc.compute.0,
                         score = "mlik",
@@ -204,7 +204,7 @@ test_that("mcmcabn",{
   data.param.0 <- matrix(data = c(0,0,1,0,0,1,1,0,0,1,0,0,0,0,0,0,0,0,0,1,0,0,1,0,1),nrow = 5L,ncol = 5L,byrow = T)
   colnames(data.param.0) <- rownames(data.param.0) <- names(dist)
 
-  out.sim.0 <- invisible(simulateabn(data.dists = dist,n.chains = 1,n.adapt = 20,n.thin = 1,n.iter = 100,data.param = data.param.0, simulate = TRUE,seed = 132))
+  out.sim.0 <- invisible(simulateAbn(data.dists = dist,n.chains = 1,n.adapt = 20,n.thin = 1,n.iter = 100,data.param = data.param.0, simulate = TRUE,seed = 132))
 
   bsc.compute.0 <- buildscorecache(data.df = out.sim.0, data.dists = dist,  max.parents = 2)
 
@@ -318,17 +318,17 @@ test_that("mcmcabn",{
                            data.dists = dist.asia,
                            max.parents = 2,
                            mcmc.scheme = c(500,0,0),
-                           seed = 456,
+                           seed = 341,
                            verbose = FALSE,
                            start.dag = "random",
-                           prob.rev = 0.1,
-                           prob.mbr = 0.1,
+                           prob.rev = 0.2,
+                           prob.mbr = 0.2,
                            prior.choice = 2)
 
 
   #maximum scoring network using exact search (not MCMC based)
   dag <- mostprobable(score.cache = bsc.compute.asia)
-  expect_equal(max(mcmc.out.asia$scores),fitabn(dag.m = dag,data.df = asia,data.dists = dist.asia)$mlik)
+  expect_equal(max(mcmc.out.asia$scores),fitabn(object = dag,data.df = asia,data.dists = dist.asia)$mlik)
 
   mcmc.out.asia <- mcmcabn(score.cache = bsc.compute.asia,
                            score = "mlik",
@@ -342,7 +342,7 @@ test_that("mcmcabn",{
                            prob.mbr = 0.1,
                            prior.choice = 2)
 
-  expect_equal(max(mcmc.out.asia$scores),fitabn(dag.m = dag,data.df = asia,data.dists = dist.asia)$mlik)
+  expect_equal(max(mcmc.out.asia$scores),fitabn(object = dag,data.df = asia,data.dists = dist.asia)$mlik)
 
   ## marks datasets
 
@@ -378,7 +378,7 @@ test_that("mcmcabn",{
 
   #maximum scoring network using exact search (not MCMC based)
   dag <- mostprobable(score.cache = bsc.compute.marks)
-  expect_equal(max(mcmc.out.marks$scores),fitabn(dag.m = dag,data.df = marks,data.dists = dist.marks)$mlik)
+  expect_equal(max(mcmc.out.marks$scores),fitabn(object = dag,data.df = marks,data.dists = dist.marks)$mlik)
 
   ##tests
   data(gaussian.test)
@@ -403,7 +403,7 @@ test_that("mcmcabn",{
                             data.dists = dist.gaussian.test,
                             max.parents = 2,
                             mcmc.scheme = c(250,0,0),
-                            seed = 678,
+                            seed = 123,
                             verbose = FALSE,
                             start.dag = "random",
                             prob.rev = 0.1,
@@ -414,7 +414,7 @@ test_that("mcmcabn",{
 
   #maximum scoring network using exact search (not MCMC based)
   dag <- mostprobable(score.cache = bsc.compute.gaussian.test)
-  expect_equal(max(mcmc.out.gaussian.test$scores),fitabn(dag.m = dag,data.df = gaussian.test,data.dists = dist.gaussian.test)$mlik)
+  expect_equal(max(mcmc.out.gaussian.test$scores),fitabn(object = dag,data.df = gaussian.test,data.dists = dist.gaussian.test)$mlik)
 
   })
 
